/**
 * SmartProxy main module exports
 */

// Legacy exports (to maintain backward compatibility)
// Migrated to the new proxies structure
export * from './proxies/nftables-proxy/index.js';

// Export NetworkProxy elements selectively to avoid RouteManager ambiguity
export { NetworkProxy, CertificateManager, ConnectionPool, RequestHandler, WebSocketHandler } from './proxies/network-proxy/index.js';
export type { IMetricsTracker, MetricsTracker } from './proxies/network-proxy/index.js';
export * from './proxies/network-proxy/models/index.js';
export { RouteManager as NetworkProxyRouteManager } from './proxies/network-proxy/models/types.js';

// Export port80handler elements selectively to avoid conflicts
export {
  Port80Handler,
  Port80HandlerError as HttpError,
  ServerError,
  CertificateError
} from './http/port80/port80-handler.js';
// Use re-export to control the names
export { Port80HandlerEvents } from './certificate/events/certificate-events.js';

export * from './redirect/classes.redirect.js';

// Export SmartProxy elements selectively to avoid RouteManager ambiguity
export { SmartProxy, ConnectionManager, SecurityManager, TimeoutManager, TlsManager, NetworkProxyBridge, RouteConnectionHandler } from './proxies/smart-proxy/index.js';
export { RouteManager } from './proxies/smart-proxy/route-manager.js';
export * from './proxies/smart-proxy/models/index.js';
export * from './proxies/smart-proxy/utils/index.js';

// Original: export * from './smartproxy/classes.pp.snihandler.js'
// Now we export from the new module
export { SniHandler } from './tls/sni/sni-handler.js';
// Original: export * from './smartproxy/classes.pp.interfaces.js'
// Now we export from the new module
export * from './proxies/smart-proxy/models/interfaces.js';

// Core types and utilities
export * from './core/models/common-types.js';

// Modular exports for new architecture
export * as forwarding from './forwarding/index.js';
export * as certificate from './certificate/index.js';
export * as tls from './tls/index.js';
export * as http from './http/index.js';